@@ -53,6 +53,7 @@
 
 // Bound library includes
 #include <QtTest/qtestmouse.h>
+#include <QtTest/qabstractitemmodeltester.h>
 #include <QtTest/qttestglobal.h>
 #include <QtTest/qbenchmarkmetric.h>
 #include <QtTest/qtestkeyboard.h>
@@ -77,13 +78,15 @@
 
 // Type indices
 enum : int {
-    SBK_QTEST_TESTFAILMODE_IDX                               = 5,
-    SBK_QTEST_QBENCHMARKMETRIC_IDX                           = 4,
-    SBK_QTEST_KEYACTION_IDX                                  = 1,
-    SBK_QTEST_MOUSEACTION_IDX                                = 2,
-    SBK_QtTestQTEST_IDX                                      = 0,
-    SBK_QTEST_PYSIDEQTOUCHEVENTSEQUENCE_IDX                  = 3,
-    SBK_QtTest_IDX_COUNT                                     = 6
+    SBK_QABSTRACTITEMMODELTESTER_FAILUREREPORTINGMODE_IDX    = 1,
+    SBK_QABSTRACTITEMMODELTESTER_IDX                         = 0,
+    SBK_QTEST_TESTFAILMODE_IDX                               = 7,
+    SBK_QTEST_QBENCHMARKMETRIC_IDX                           = 6,
+    SBK_QTEST_KEYACTION_IDX                                  = 3,
+    SBK_QTEST_MOUSEACTION_IDX                                = 4,
+    SBK_QtTestQTEST_IDX                                      = 2,
+    SBK_QTEST_PYSIDEQTOUCHEVENTSEQUENCE_IDX                  = 5,
+    SBK_QtTest_IDX_COUNT                                     = 8
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide2_QtTestTypes;
@@ -96,10 +99,12 @@ extern SbkConverter **SbkPySide2_QtTestTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTTEST_QLIST_QVARIANT_IDX                            = 0, // QList<QVariant >
-    SBK_QTTEST_QLIST_QSTRING_IDX                             = 1, // QList<QString >
-    SBK_QTTEST_QMAP_QSTRING_QVARIANT_IDX                     = 2, // QMap<QString,QVariant >
-    SBK_QtTest_CONVERTERS_IDX_COUNT                          = 3
+    SBK_QTTEST_QLIST_QOBJECTPTR_IDX                          = 0, // const QList<QObject* > &
+    SBK_QTTEST_QLIST_QBYTEARRAY_IDX                          = 1, // QList<QByteArray >
+    SBK_QTTEST_QLIST_QVARIANT_IDX                            = 2, // QList<QVariant >
+    SBK_QTTEST_QLIST_QSTRING_IDX                             = 3, // QList<QString >
+    SBK_QTTEST_QMAP_QSTRING_QVARIANT_IDX                     = 4, // QMap<QString,QVariant >
+    SBK_QtTest_CONVERTERS_IDX_COUNT                          = 5
 };
 // Macros for type check
 
@@ -109,6 +114,8 @@ namespace Shiboken
 // PyType functions, to get the PyObjectType for a type T
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
+template<> inline PyTypeObject *SbkType< ::QAbstractItemModelTester::FailureReportingMode >() { return SbkPySide2_QtTestTypes[SBK_QABSTRACTITEMMODELTESTER_FAILUREREPORTINGMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QAbstractItemModelTester >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtTestTypes[SBK_QABSTRACTITEMMODELTESTER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QTest::TestFailMode >() { return SbkPySide2_QtTestTypes[SBK_QTEST_TESTFAILMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QTest::QBenchmarkMetric >() { return SbkPySide2_QtTestTypes[SBK_QTEST_QBENCHMARKMETRIC_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QTest::KeyAction >() { return SbkPySide2_QtTestTypes[SBK_QTEST_KEYACTION_IDX]; }
