@@ -49,9 +49,9 @@
 // Module Includes
 #include <pyside2_qtcore_python.h>
 
-// Binded library includes
-#include <qwebchannel.h>
-#include <qwebchannelabstracttransport.h>
+// Bound library includes
+#include <QtWebChannel/qwebchannel.h>
+#include <QtWebChannel/qwebchannelabstracttransport.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
@@ -77,13 +77,13 @@ enum : int {
     SBK_QtWebChannel_IDX_COUNT                               = 2
 };
 // This variable stores all Python types exported by this module.
-extern PyTypeObject** SbkPySide2_QtWebChannelTypes;
+extern PyTypeObject **SbkPySide2_QtWebChannelTypes;
 
 // This variable stores the Python module object exported by this module.
-extern PyObject* SbkPySide2_QtWebChannelModuleObject;
+extern PyObject *SbkPySide2_QtWebChannelModuleObject;
 
 // This variable stores all type converters exported by this module.
-extern SbkConverter** SbkPySide2_QtWebChannelTypeConverters;
+extern SbkConverter **SbkPySide2_QtWebChannelTypeConverters;
 
 // Converter indices
 enum : int {
@@ -101,8 +101,11 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QWebChannel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebChannelTypes[SBK_QWEBCHANNEL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QWebChannelAbstractTransport >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebChannelTypes[SBK_QWEBCHANNELABSTRACTTRANSPORT_IDX]); }
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+template<> inline PyTypeObject *SbkType< ::QWebChannel >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtWebChannelTypes[SBK_QWEBCHANNEL_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QWebChannelAbstractTransport >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtWebChannelTypes[SBK_QWEBCHANNELABSTRACTTRANSPORT_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
